@@ -1,25 +1,26 @@
 package ex::interface;
 
 use strict;
+no strict 'refs';
 
 require 5.6.0;
-our $VERSION = "0.1";
+our $VERSION = "0.2";
 
 
 sub import {
     my $self = shift;
     my %__METHOD = map {$_ => 1} @_;
     my $interface = caller;
-    $interface .= '::';
-    $::{$interface}{__METHOD} = \%__METHOD;
-    $::{$interface}{AUTOLOAD} = \&their_AUTOLOAD;
+    *{"$interface\::__METHOD"} = \%__METHOD;
+    *{"$interface\::AUTOLOAD"} = \&their_AUTOLOAD;
 }
 
 sub their_AUTOLOAD {
     our $AUTOLOAD = $AUTOLOAD;
     $AUTOLOAD =~ s/(.*):://;
+    return if $AUTOLOAD eq 'DESTROY';
     my $interface = $1;
-    if ($ {$::{"$interface\::__METHOD"}{$AUTOLOAD}}) {
+    if ($ {"$interface\::__METHOD"}{$AUTOLOAD}) {
         require Carp;
         Carp::croak("The interface method '$AUTOLOAD' has not been implemented");
     }
@@ -29,4 +30,7 @@ sub their_AUTOLOAD {
         $self->$AUTOLOAD(@_);
     }
 }
+
+sub DESTROY { return }
+
 1;
