@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..4\n"; }
+BEGIN { $| = 1; print "1..5\n"; }
 END {print "not ok 1\n" unless $loaded;}
 require ex::implements;
 require ex::interface;
@@ -44,5 +44,15 @@ sub foo; sub bar; sub bletch;' 2>&1`;
 
 $error =~ s{^Using.*/blib\n}{}m;
 
-print "not " if $@;
+print "not " if $error;
 print "ok 4\n";
+
+$error =
+    `perl -Mblib -e 'package Interface; use ex::interface qw/foo bar bletch/;\
+package Working; \
+use ex::implements qw/Interface/; \
+sub foo; sub bar; sub bletch;
+print "ISA not set" unless Working->isa("Interface")' 2>/dev/null`;
+
+print "not " if $error =~ /ISA not set/;
+print "ok 5\n";
